==> tutti-ui-swing-2.9-sources.jar: fr/ifremer/tutti/ui/swing/content/report/ReportUIHandler.java <==
package fr.ifremer.tutti.ui.swing.content.report;

/*
 * #%L
 * Tutti :: UI
 * $Id: ReportUIHandler.java 1344 2013-11-12 09:10:29Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-2.9/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/report/ReportUIHandler.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.base.Preconditions;
import com.google.common.collect.Lists;
import fr.ifremer.tutti.service.report.ReportService;
import fr.ifremer.tutti.ui.swing.TuttiUIContext;
import fr.ifremer.tutti.ui.swing.util.AbstractTuttiUIHandler;
import fr.ifremer.tutti.ui.swing.util.CloseableUI;
import fr.ifremer.tutti.ui.swing.util.TuttiUI;
import fr.ifremer.tutti.ui.swing.util.TuttiUIUtil;
import jaxx.runtime.swing.editor.FileEditor;
import jaxx.runtime.validator.swing.SwingValidator;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import javax.swing.JComponent;
import java.awt.Desktop;
import java.io.File;
import java.io.IOException;
import java.util.List;

import static org.nuiton.i18n.I18n._;

/**
 * Handler of {@link ReportUI}.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 2.9
 */
public class ReportUIHandler extends AbstractTuttiUIHandler<ReportUIModel, ReportUI> implements CloseableUI {

    /** Logger. */
    private static final Log log = LogFactory.getLog(ReportUIHandler.class);

    /**
     * Persistence service.
     *
     * @since 0.1
     */
    private final ReportService reportService;

    public ReportUIHandler(TuttiUI parentUi, ReportUI ui) {
        super(parentUi.getHandler().getContext(), ui);
        this.reportService = context.getReportService();
    }

    @Override
    public void beforeInitUI() {

        getDataContext().resetValidationDataContext();

        ReportUIModel model = new ReportUIModel();

        // get all report availables
        List<File> reports = reportService.getAvailableReports();
        model.setReports(reports);

        // get default output file name
        File outputFile = reportService.getDefaultOutputFile();
        model.setOutputFile(outputFile);

        listModelIsModify(model);

        ui.setContextValue(model);
    }

    @Override
    public void afterInitUI() {

        initUI(ui);

        ReportUIModel model = getModel();

        initBeanFilterableComboBox(ui.getReportComboBox(),
                                   Lists.newArrayList(model.getReports()),
                                   model.getReport());

        FileEditor inputFileField = ui.getInputFileField();
        inputFileField.setDirectoryEnabled(false);
        inputFileField.setFileEnabled(true);
        inputFileField.setExts(".csv");
        inputFileField.setExtsDescription("Fichier csv");

        FileEditor outputFileField = ui.getOutputFileField();
        outputFileField.setDirectoryEnabled(false);
        outputFileField.setFileEnabled(true);
        outputFileField.setExts(".pdf");
        outputFileField.setExtsDescription("Fichier pdf");

        SwingValidator validator = ui.getValidator();
        listenValidatorValid(validator, model);

        registerValidators(validator);
    }

    @Override
    protected JComponent getComponentToFocus() {
        return getUI().getReportComboBox();
    }

    @Override
    public void onCloseUI() {
        if (log.isDebugEnabled()) {
            log.debug("closing: " + ui);
        }
        clearValidators();
    }

    @Override
    public boolean quitUI() {
        return true;
    }

    @Override
    public SwingValidator<ReportUIModel> getValidator() {
        return ui.getValidator();
    }

    public void showReport() {

        File file = getModel().getOutputFile();

        Preconditions.checkState(file.exists());

        Desktop desktop = TuttiUIUtil.getDesktopForBrowse();
        try {
            desktop.browse(file.toURI());

        } catch (IOException e) {
            TuttiUIContext.getErrorHelper().showErrorDialog(_("swing.error.cannot.open.file"));
        }
    }

}

==> tutti-ui-swing-3.0-sources.jar: fr/ifremer/tutti/ui/swing/content/report/ReportUIHandler.java <==
package fr.ifremer.tutti.ui.swing.content.report;

/*
 * #%L
 * Tutti :: UI
 * $Id: ReportUIHandler.java 1436 2013-12-09 13:51:06Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-3.0/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/report/ReportUIHandler.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.base.Preconditions;
import com.google.common.collect.Lists;
import fr.ifremer.shared.application.swing.util.CloseableUI;
import fr.ifremer.tutti.persistence.entities.data.FishingOperation;
import fr.ifremer.tutti.service.report.ReportService;
import fr.ifremer.tutti.ui.swing.util.AbstractTuttiUIHandler;
import fr.ifremer.tutti.ui.swing.util.TuttiUIUtil;
import jaxx.runtime.swing.editor.FileEditor;
import jaxx.runtime.validator.swing.SwingValidator;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import javax.swing.JComponent;
import java.awt.Desktop;
import java.io.File;
import java.io.IOException;
import java.util.List;

import static org.nuiton.i18n.I18n._;

/**
 * Handler of {@link ReportUI}.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 2.9
 */
public class ReportUIHandler extends AbstractTuttiUIHandler<ReportUIModel, ReportUI> implements CloseableUI {

    /** Logger. */
    private static final Log log = LogFactory.getLog(ReportUIHandler.class);

    @Override
    public void beforeInit(ReportUI ui) {

        super.beforeInit(ui);

        ReportService reportService = getContext().getReportService();

        ReportUIModel model = new ReportUIModel();

        // set cruiseId
        String cruiseId = getDataContext().getCruiseId();
        model.setCruiseId(cruiseId);

        // get all report availables
        List<File> reports = reportService.getAvailableReports();
        model.setReports(reports);

        // get all fishing operation
        List<FishingOperation> fishingOperations =
                getContext().getPersistenceService().getAllFishingOperation(cruiseId);
        model.setFishingOperations(fishingOperations);

        // get default output file name
        File outputFile = reportService.getDefaultOutputFile();
        model.setOutputFile(outputFile);

        listModelIsModify(model);

        ui.setContextValue(model);
    }

    @Override
    public void afterInit(ReportUI ui) {

        initUI(ui);

        ReportUIModel model = getModel();

        initBeanFilterableComboBox(ui.getReportComboBox(),
                                   Lists.newArrayList(model.getReports()),
                                   model.getReport());

        initBeanFilterableComboBox(ui.getFishingOperationComboBox(),
                                   Lists.newArrayList(model.getFishingOperations()),
                                   model.getFishingOperation());

        FileEditor outputFileField = ui.getOutputFileField();
        outputFileField.setDirectoryEnabled(false);
        outputFileField.setFileEnabled(true);
        outputFileField.setExts(".pdf");
        outputFileField.setExtsDescription(_("tutti.common.file.pdf"));

        SwingValidator validator = ui.getValidator();
        listenValidatorValid(validator, model);

        registerValidators(validator);
    }

    @Override
    protected JComponent getComponentToFocus() {
        return getUI().getFishingOperationComboBox();
    }

    @Override
    public void onCloseUI() {
        if (log.isDebugEnabled()) {
            log.debug("closing: " + ui);
        }
        clearValidators();
    }

    @Override
    public boolean quitUI() {
        return true;
    }

    @Override
    public SwingValidator<ReportUIModel> getValidator() {
        return ui.getValidator();
    }

    public void showReport() {

        File file = getModel().getOutputFile();

        Preconditions.checkState(file.exists());

        Desktop desktop = TuttiUIUtil.getDesktopForBrowse();
        try {
            desktop.browse(file.toURI());

        } catch (IOException e) {
            getContext().getErrorHelper().showErrorDialog(_("swing.error.cannot.open.file"));
        }
    }

}
